==> zio-aws-lookoutequipment_2.12-5.17.145.1-sources.jar: zio/aws/lookoutequipment/model/InferenceS3OutputConfiguration.scala <==
package zio.aws.lookoutequipment.model
import zio.ZIO
import zio.aws.lookoutequipment.model.primitives.{S3Prefix, S3Bucket}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InferenceS3OutputConfiguration(
    bucket: S3Bucket,
    prefix: Option[S3Prefix] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration = {
    import InferenceS3OutputConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
      .builder()
      .bucket(S3Bucket.unwrap(bucket): java.lang.String)
      .optionallyWith(
        prefix.map(value => S3Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .build()
  }
  def asReadOnly
      : zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration.ReadOnly =
    zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration
      .wrap(buildAwsValue())
}
object InferenceS3OutputConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration =
      zio.aws.lookoutequipment.model
        .InferenceS3OutputConfiguration(bucket, prefix.map(value => value))
    def bucket: S3Bucket
    def prefix: Option[S3Prefix]
    def getBucket: ZIO[Any, Nothing, S3Bucket] = ZIO.succeed(bucket)
    def getPrefix: ZIO[Any, AwsError, S3Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
  ) extends zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration.ReadOnly {
    override val bucket: S3Bucket =
      zio.aws.lookoutequipment.model.primitives.S3Bucket(impl.bucket())
    override val prefix: Option[S3Prefix] = scala
      .Option(impl.prefix())
      .map(value => zio.aws.lookoutequipment.model.primitives.S3Prefix(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
  ): zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lookoutequipment_2.12-5.20.7.3-sources.jar: zio/aws/lookoutequipment/model/InferenceS3OutputConfiguration.scala <==
package zio.aws.lookoutequipment.model
import zio.ZIO
import zio.aws.lookoutequipment.model.primitives.{S3Prefix, S3Bucket}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InferenceS3OutputConfiguration(
    bucket: S3Bucket,
    prefix: Optional[S3Prefix] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration = {
    import InferenceS3OutputConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
      .builder()
      .bucket(S3Bucket.unwrap(bucket): java.lang.String)
      .optionallyWith(
        prefix.map(value => S3Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .build()
  }
  def asReadOnly
      : zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration.ReadOnly =
    zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration
      .wrap(buildAwsValue())
}
object InferenceS3OutputConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration =
      zio.aws.lookoutequipment.model
        .InferenceS3OutputConfiguration(bucket, prefix.map(value => value))
    def bucket: S3Bucket
    def prefix: Optional[S3Prefix]
    def getBucket: ZIO[Any, Nothing, S3Bucket] = ZIO.succeed(bucket)
    def getPrefix: ZIO[Any, AwsError, S3Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
  ) extends zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration.ReadOnly {
    override val bucket: S3Bucket =
      zio.aws.lookoutequipment.model.primitives.S3Bucket(impl.bucket())
    override val prefix: Optional[S3Prefix] = zio.aws.core.internal
      .optionalFromNullable(impl.prefix())
      .map(value => zio.aws.lookoutequipment.model.primitives.S3Prefix(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lookoutequipment.model.InferenceS3OutputConfiguration
  ): zio.aws.lookoutequipment.model.InferenceS3OutputConfiguration.ReadOnly =
    new Wrapper(impl)
}
